from django.contrib.auth.models import AbstractUser
from django.db import models
from datetime import datetime
from django.utils import timezone
from django.contrib.auth.models import User
from django.db.models.signals import post_save
from django.dispatch import receiver

# Create your models here.

class Employees(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE)
    full_name = models.CharField(max_length=300)
    dob = models.DateField(default = timezone.now)
    gen_der = models.CharField(max_length=300)
    age       = models.CharField(max_length=20)

    def __str__(self):
        return f'{self.full_name}-{self.gen_der}'
        
class Profile(models.Model):
    SUPERVISOR = 1
    EMPLOYEES = 2
    ROLE_CHOICES = (   
        (SUPERVISOR, 'Supervisor'), 
        (EMPLOYEES, 'Employees'),
    )
    user = models.OneToOneField(User, on_delete=models.CASCADE)
    location = models.CharField(max_length=30, blank=True)
    birthdate = models.DateField(null=True, blank=True)
    role = models.PositiveSmallIntegerField(choices=ROLE_CHOICES, null=True, blank=True)

    def __str__(self):  # __unicode__ for Python 2
        return self.user.username

@receiver(post_save, sender=User)
def create_or_update_user_profile(sender, instance, created, **kwargs):
    if created:
        Profile.objects.create(user=instance)
        instance.profile.save()        


class Incustumer(models.Model):
    in_id = models.AutoField(primary_key=True)
    card_id =models.CharField(max_length=200, unique=True)
    face_id = models.IntegerField(null=True,blank=True, max_length=200) 
    first_name = models.CharField(max_length=300)
    last_name = models.CharField(max_length=300)
    phone = models.CharField(max_length=20)
    gender= models.CharField(max_length=300)
    age       = models.CharField(max_length=20)
    email = models.EmailField(null=True, unique=True)
    point = models.IntegerField(default = 0)
    career = models.CharField(max_length=300)

    
    def __str__(self):
        return f'{self.in_id}' 


class Product (models.Model):
    P_TYPE = (
        ('HOT', 'hot'),
        ('COLD', 'cold'),
        ('BLENDED', 'blended'),
    )

    Pid = models.AutoField(primary_key=True)
    P_name = models.CharField(max_length=1000)
    P_nameEng =models.CharField(max_length=1000)
    price = models.IntegerField(max_length=300)
    p_type =models.CharField(max_length=10,choices=P_TYPE, null=True, blank=True)
    created_at = models.DateTimeField(default=datetime.now, blank=True)

    def __str__(self):
        return f'{self.Pid} {self.P_name} {self.p_type} '

class Order(models.Model):   
    Oid      = models.AutoField(primary_key=True)  
    Emp = models.ForeignKey(User, on_delete=models.CASCADE, null= True, unique=False)
    user = models.ForeignKey(Incustumer, on_delete=models.CASCADE, unique=False)
    product  = models.ForeignKey(Product, on_delete=models.CASCADE, unique=False)
    sum_Order = models.IntegerField(max_length=300)
    created_at = models.DateTimeField(default=datetime.now, blank=True)
    
    def __str__(self):
        return f'{self.Oid}'



